==> ae_kivy_app-0.1.74.tar.gz: ae_kivy_app-0.1.74/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# kivy_app portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_app/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_app)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_app/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_app/coverage/ae_kivy_app_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_app/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_app/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_app/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_app/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_app)](
    https://libraries.io/pypi/ae-kivy-app)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/#files)


## installation


Execute the following command for to use the ae.kivy_app module in your
application. It will install ae.kivy_app into your python (virtual) environment:
 
```shell script
pip install ae-kivy-app
```

If you instead want to contribute to this portion then first fork
[the ae_kivy_app repository at GitLab](https://gitlab.com/ae-group/ae_kivy_app "ae.kivy_app code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_app):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_app.html#module-ae.kivy_app
"ae_kivy_app documentation").

<!-- Common files version 0.0.60 deployed version 0.1.36 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_kivy_app module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-app as namespace portion ae-kivy-app.
-->

==> ae_kivy_app-0.2.101.tar.gz: ae_kivy_app-0.2.101/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# kivy_app portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_app/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_app)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_app/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_app/coverage/ae_kivy_app_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_app/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_app/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_app/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_app/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_app)](
    https://libraries.io/pypi/ae-kivy-app)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_app)](
    https://pypi.org/project/ae-kivy-app/#files)


## installation


execute the following command to use the ae.kivy_app sub-package in your
application. it will install ae.kivy_app into your python (virtual) environment:
 
```shell script
pip install ae-kivy-app
```

if you instead want to contribute to this portion then first fork
[the ae_kivy_app repository at GitLab](https://gitlab.com/ae-group/ae_kivy_app "ae.kivy_app code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_app):

```shell script
pip install -e .[dev]
```

the last command will install this sub-package portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_app.html#module-ae.kivy_app
"ae_kivy_app documentation").

<!-- common files version 0.2.77 deployed version 0.2.94 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_kivy_app sub-package as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-app as namespace portion ae-kivy-app.
-->
